@@ -74,7 +74,7 @@ sub Read
 				 grep $Songs::Def{$_}{flags}=~m/r/, @Songs::Fields;
 	for my $field (@fields)
 	{	for (my $i=0; $i<$#taglist; $i+=2)
-		{	my $id=$taglist[$i]; #$id is type of tag : id3v1 id3v2 ape vorbis lyrics3 ilst
+		{	my $id=$taglist[$i]; #$id is type of tag : id3v1 id3v2 ape vorbis lyrics3v2 ilst
 			my $tag=$taglist[$i+1];
 			my $value;
 			my $def=$Songs::Def{$field};
@@ -134,17 +134,20 @@ sub Write
 		while ($i<$#$modif)
 		{	my $field=$modif->[$i++];
 			my $val=  $modif->[$i++];
-			my $i=$Songs::Def{$field}{id3v1};
-			next unless defined $i;
-			$id3v1->[$i]= $val;	# for genres $val is a arrayref
+			my $n=$Songs::Def{$field}{id3v1};
+			next unless defined $n;
+			$id3v1->[$n]= $val;	# for genres $val is a arrayref
 		}
 	}
 
 	my @taglist;
 	if ($maintag eq 'ID3v2' || $tag->{ID3v2})
-	{	my $id3v2 = $tag->{ID3v2} || $tag->new_ID3v2;
-		my ($ver)= $id3v2->{version}=~m/^(\d+)/;
-		push @taglist, ["id3v2.$ver",'id3v2'], $id3v2;
+	{	my @id3tags= ($tag->{ID3v2} || $tag->new_ID3v2);
+		push @id3tags, @{$tag->{ID3v2s}} if $tag->{ID3v2s};
+		for my $id3tag (@id3tags)
+		{	my ($ver)= $id3tag->{version}=~m/^(\d+)/;
+			push @taglist, ["id3v2.$ver",'id3v2'], $id3tag;
+		}
 	}
 	if ($maintag eq 'vorbis' || $maintag eq 'ilst')
 	{	push @taglist, $maintag,$tag;
@@ -490,8 +493,8 @@ sub add_column
 {	my ($self,$field)=@_;
 	if ($self->{'pfcheck_'.$field})	#if already created -> toggle show/hide
 	{	my @w=( $self->{'pfcheck_'.$field}, @{ $self->{pf_widgets}{$field} } );
-		if ($w[0]->visible)	{ $_->hide for @w; }
-		else			{ $_->show for @w; }
+		my $show= !$w[0]->visible;
+		$_->set_visible($show) for @w;
 		return;
 	}
 	my $table=$self->{perfile_table};
@@ -544,8 +547,8 @@ sub add_column
 sub add_selectfile_column
 {	my $self=$_[0];
 	if (my $l=$self->{'filetoggles'})	#if already created -> toggle show/hide
-	{	if ($l->[0]->visible)	{ $_->hide for @$l; }
-		else			{ $_->show for @$l; }
+	{	my $show= !$l->[0]->visible;
+		$_->set_visible($show) for @$l;
 		return;
 	}
 	my @toggles;
@@ -708,9 +711,14 @@ package GMB::Edit::Autofill_formats;
 use base 'Gtk2::Dialog';
 our $Instance;
 
+our %Override;
+INIT
+{	%Override= ('%A'=> '$album_artist_raw');
+}
+
 sub new
 {	my $ID= $_[0]{IDs}[0];
-	if ($Instance) { $Instance->present; $Instance->{ID}=$ID; $Instance->preview_update; return };
+	if ($Instance) { $Instance->force_present; $Instance->{ID}=$ID; $Instance->preview_update; return };
 	my $self = Gtk2::Dialog->new ("Custom auto-fill filename formats", undef, [],  'gtk-close' => 'none');
 	$Instance=bless $self,__PACKAGE__;
 	::SetWSize($self,'AutofillFormats');
@@ -740,7 +748,7 @@ sub new
 	$sg->add_widget($_) for $label_format,$label_re;
 	my $bbox= Gtk2::HButtonBox->new;
 	$bbox->add($_) for $button_del, $button_add, $button_new;
-	my $table= ::MakeReplaceTable('taAlCyndgL');	#AutoFillFields
+	my $table= ::MakeReplaceTable('taAlCyndgL', A=>Songs::FieldName('album_artist_raw'));	#AutoFillFields
 	my $hbox= ::Hpack($treeview,'_',[[$label_format,'_',$entry_format],$table,$check_re,[$label_re,'_',$entry_re],$error,$preview,'-',$bbox]);
 	$self->vbox->add($hbox);
 
@@ -860,7 +868,7 @@ sub fill_store
 sub make_format_name
 {	my ($format,$markup)=@_;
 	$format=~s#(\$\w+|%[a-zA-Z]|\$\{\w+\})|([%\$])\2#
-		   $2 || do {	my $f= $::ReplaceFields{$1};
+		   $2 || do {	my $f= $::ReplaceFields{ $Override{$1}||$1 };
 		   		$f=undef if $f && $Songs::Def{$f}{flags}!~m/e/;
 				$f&&= Songs::FieldName($f);
 				$f&&= ::MarkupFormat($markup,$f) if $markup;
@@ -870,14 +878,14 @@ sub make_format_name
 }
 sub find_fields
 {	my $format=shift;
-	my @fields= map $::ReplaceFields{$_}, grep defined, $format=~m/ %% | \$\$ | ( \$\w+ | %[a-zA-Z] | \$\{\w+\} ) /gx;
+	my @fields= map $::ReplaceFields{$Override{$_}||$_}, grep defined, $format=~m/ %% | \$\$ | ( \$\w+ | %[a-zA-Z] | \$\{\w+\} ) /gx;
 	@fields= grep defined && $Songs::Def{$_}{flags}=~m/e/, @fields;
 	return @fields;
 }
 sub make_default_re
 {	my $re=shift;
 	$re=~s#(\$\w+|%[a-zA-Z]|\$\{\w+\})|%(%)|\$(\$)|(%?[-,;\w ]+)|(.)#
-		$1 ? Songs::ReplaceFields_to_re($1) :
+		$1 ? Songs::ReplaceFields_to_re( $Override{$1}||$1 ) :
 		$2 ? $2 : $3 ? '\\'.$3 : defined $4 ? $4 : '\\'.$5 #ge;
 	return $re;
 }
@@ -928,7 +936,9 @@ sub new
 	my $sw = Gtk2::ScrolledWindow->new;
 	 $sw->set_shadow_type('etched-in');
 	 $sw->set_policy('automatic','automatic');
-	$sw->add( $self->{textview}=Gtk2::TextView->new );
+	my $textview= $self->{textview}= Gtk2::TextView->new;
+	$textview->set_size_request(100,($textview->create_pango_layout("X")->get_pixel_size)[1]*4); #request 4 lines of height
+	$sw->add($textview);
 	$self->add($sw);
 	my $val;
 	if (ref $IDs)
@@ -1154,17 +1164,20 @@ sub new
 	my $self = bless Gtk2::HBox->new(0,0), $class;
 	$self->{field}=$field;
 	$self->{ID}=$ID;
+	my $button= Gtk2::Button->new;
+	my $add= ::NewIconButton('gtk-add');
+	my $entry= $self->{entry}= Gtk2::Entry->new;
 	my $label=$self->{label}=Gtk2::Label->new;
 	$label->set_ellipsize('end');
-	my $button= Gtk2::Button->new;
-	my $entry= Gtk2::Entry->new;
 	$entry->set_width_chars(12);
 	$button->add($label);
 	$self->pack_start($button,1,1,0);
 	$self->pack_start($entry,0,0,0);
+	$self->pack_start($add,0,0,0);
+	$add->signal_connect( button_press_event => sub { add_entry_text_cb($_[0]); $_[0]->grab_focus;1; } );
 	$button->signal_connect( clicked => \&popup_menu_cb);
 	$button->signal_connect( button_press_event => sub { popup_menu_cb($_[0]); $_[0]->grab_focus;1; } );
-	$entry->signal_connect( activate => \&entry_activate_cb );
+	$entry->signal_connect( activate => \&add_entry_text_cb );
 	GMB::ListStore::Field::setcompletion($entry,$field);
 
 	$self->{selected}{$_}=1 for Songs::Get_list($ID,$field);
@@ -1173,15 +1186,16 @@ sub new
 	return $self;
 }
 
-sub entry_activate_cb
-{	my $entry=$_[0];
-	my $self=::find_ancestor($entry,__PACKAGE__);
+sub add_entry_text_cb
+{	my $widget=shift;
+	my $self=::find_ancestor($widget,__PACKAGE__);
+	my $entry=$self->{entry};
 	my $text=$entry->get_text;
-	if ($text eq '') { popup_add_menu($self,$entry); return }
-	#return if $text eq '';
-	$self->{selected}{ $text }=1;
-	$self->update;
+	if ($text eq '') { $self->popup_add_menu($widget); return }
+	# split $text ?
+	$self->{selected}{$text}=1;
 	$entry->set_text('');
+	$self->update;
 }
 
 sub popup_add_menu
@@ -1252,7 +1266,7 @@ sub new
 	$self->{field}=$field;
 	my $sg= Gtk2::SizeGroup->new('horizontal');
 	my $entry= $self->{entry}= Gtk2::Entry->new;
-	my $add= ::NewIconButton('gtk-add', undef, \&add_entry_text_cb);
+	my $add= ::NewIconButton('gtk-add');
 	my $removeall= ::NewIconButton('gtk-clear', _"Remove all", \&clear);
 	$add->signal_connect( button_press_event => sub { add_entry_text_cb($_[0]); $_[0]->grab_focus;1; } );
 	for my $ref (['toadd',1,_"Add"],['toremove',-1,_"Remove"])
@@ -1935,7 +1949,9 @@ sub new
 	my $self = bless Gtk2::ScrolledWindow->new, $class;
 	 $self->set_shadow_type('etched-in');
 	 $self->set_policy('automatic','automatic');
-	$self->add( $self->{textview}=Gtk2::TextView->new );
+	my $textview= $self->{textview}= Gtk2::TextView->new;
+	$textview->set_size_request(100,($textview->create_pango_layout("X")->get_pixel_size)[1]*4); #request 4 lines of height
+	$self->add($textview);
 	$self->set_text($init);
 	$self->{init}=$self->get_text;
 	return $self;
@@ -2187,6 +2203,7 @@ sub view
 	$sw->set_policy('never', 'automatic');
 	$sw->add($textview);
 	$dialog->vbox->add($sw);
+	$dialog->set_default_size(100,100);
 	$dialog->show_all;
 	$dialog->signal_connect( response => sub { $_[0]->destroy; });
 }
@@ -2326,7 +2343,7 @@ sub return_value
 }
 sub edit
 {	my $self=$_[0];
-	if ($self->{dialog}) { $self->{dialog}->present; return }
+	if ($self->{dialog}) { $self->{dialog}->force_present; return }
 	$self->{dialog}=
 	::EditLyricsDialog( $self->get_toplevel, $self->{value},undef, sub
 		{	my $lyrics=shift;
