@@ -931,7 +931,7 @@ EQUA =>	'u',
 TDRC =>	'eT',
 TDOR =>	'eT',
 TSST =>	'eT',
-TMOO =>	'eT',
+TMOO =>	'eT*',
 TPRO =>	'eT',
 TDEN =>	'eT',
 TDRL =>	'eT',
