@@ -5,7 +5,7 @@
 # it under the terms of the GNU General Public License version 3, as
 # published by the Free Software Foundation
 
-=gmbplugin ARTISTINFO
+=for gmbplugin ARTISTINFO
 name	Artistinfo
 title	Artistinfo plugin
 version	0.5
@@ -149,7 +149,7 @@ sub new
 	$tc_artist->set_resizable(1);
 	$treeview->append_column($tc_artist);
 	$treeview->set_has_tooltip(1);
-	$treeview->set_tooltip_text("Middle-click on local artists to set a filter on them, right-click non-local artists to search for them on the web.");
+	$treeview->set_tooltip_text(_"Middle-click on local artists to set a filter on them, right-click non-local artists to search for them on the web.");
 	my $renderer=Gtk2::CellRendererText->new;
 	my $tc_similar=Gtk2::TreeViewColumn->new_with_attributes( "%",$renderer,text => 1);
 	$tc_similar->set_cell_data_func($renderer, sub { my ($column, $cell, $model, $iter, $func_data) = @_; my $rating = $model->get($iter, 1); $cell->set( text => sprintf '%.1f', $rating ); }, undef); # limit similarity rating to one decimal
@@ -260,7 +260,7 @@ sub prefbox
 	my $preview= Label::Preview->new(preview => \&filename_preview, event => 'CurSong Option', noescape=>1,wrap=>1);
 	my $autosave=::NewPrefCheckButton(OPT.'AutoSave' => _"Auto-save positive finds", tip=>_"only works when the artist-info tab is displayed");
 	my $picsize=::NewPrefSpinButton(OPT.'ArtistPicSize',50,500, step=>5, page=>10, text =>_("Artist Picture Size : %d")._"(applied after restart)");
-	my $eventformat=::NewPrefEntry(OPT.'Eventformat' => _"Enter custom event string :", width=>80, tip => _"Use tags from last.fm's XML event pages with a leading % (e.g. %headliner), furthermore linebreaks '<br>' and any text you'd like to have in between. E.g. '%title taking place at %startDate<br>in %city, %country<br><br>'", history=>OPT.'Eventformat_history');
+	my $eventformat=::NewPrefEntry(OPT.'Eventformat' => _"Enter custom event string :", expand=>1, tip => _"Use tags from last.fm's XML event pages with a leading % (e.g. %headliner), furthermore linebreaks '<br>' and any text you'd like to have in between. E.g. '%title taking place at %startDate<br>in %city, %country<br><br>'", history=>OPT.'Eventformat_history');
 	my $eventformat_reset=Gtk2::Button->new(_"reset format");
 	$eventformat_reset->{format_combo}=$eventformat;
 	$eventformat_reset->signal_connect(clicked => sub {
@@ -281,7 +281,7 @@ sub prefbox
 	my $frame_bio=Gtk2::Frame->new(_"Biography");
 	$frame_bio->add(::Vpack($entry,$preview,$autosave));
 	my $frame_events=Gtk2::Frame->new(_"Events");
-	$frame_events->add(::Hpack($eventformat,$eventformat_reset));
+	$frame_events->add(::Hpack('_',$eventformat,$eventformat_reset));
 	my $frame_similar=Gtk2::Frame->new(_"Similar Artists");
 	$frame_similar->add(::Vpack($similar_limit,$similar_rating,$similar_local,$similar_exclude_seed));
 	$vbox->pack_start($_,::FALSE,::FALSE,5) for $titlebox,$frame_bio,$frame_events,$frame_similar;
@@ -669,7 +669,7 @@ sub PopulateQueue
 	if ( $nowplayingaID != Songs::Get_gid($::SongID,'artist')) { QAutofillSimilarArtists; return; }
 	my $data = $_[0];
 
-	return unless $::QueueAction eq 'autofill-similar-artists'; # re-check queueaction and 
+	return unless $::QueueAction eq 'autofill-similar-artists'; # re-check queueaction and
 	my $nb=$::Options{MaxAutoFill}-@$::Queue;
 	return unless $nb>0;
 	my @artist_gids;
@@ -685,7 +685,7 @@ sub PopulateQueue
 	push (@artist_gids, Songs::Get_gid($::SongID,'artist')) unless $::Options{OPT.'SimilarExcludeSeed'}; # add currently playing artist as well
 
 	my $filter= Filter->newadd(0, map Songs::MakeFilterFromGID("artist",$_), @artist_gids );
-	my $random= Random->new('random:',$filter->filter);
+	my $random= Random->new('random:',$filter->filter($::ListPlay));
 	my @IDs=$random->Draw($nb,[@$::Queue,$::SongID]); # add queue and current song to blacklist (won't draw)
 	return unless @IDs;
 	$::Queue->Push(\@IDs);
