@@ -5,7 +5,7 @@
 # it under the terms of the GNU General Public License version 3, as
 # published by the Free Software Foundation
 
-=gmbplugin LYRICS
+=for gmbplugin LYRICS
 name	Lyrics
 title	Lyrics plugin
 desc	Search and display lyrics
@@ -22,7 +22,7 @@ use constant
 {	OPT	=> 'PLUGIN_LYRICS_', # MUST begin by PLUGIN_ followed by the plugin ID / package name
 };
 
-my $notfound=_"Not found";
+my $notfound=_"No lyrics found";
 
 my @justification=
 (	left	=> _"Left aligned",
@@ -61,7 +61,7 @@ my %Sites=	# id => [name,url,?post?,function]	if the function return 1 => lyrics
 		sub { my $no= $_[0]=~m/<div class="noarticletext">/s; $_[0]=~s/^.*<!--\s*start content\s*-->(.*?)<!--\s*end content\s*-->.*$/$1/s && !$no; }],
 	#lyricsplugin => [lyricsplugin => 'http://www.lyricsplugin.com/winamp03/plugin/?title=%t&artist=%a',undef,
 	#		sub { my $ok=$_[0]=~m#<div id="lyrics">.*\w\n.*\w.*</div>#s; $_[0]=~s/<div id="admin".*$//s if $ok; return $ok; }],
-	lyricssongs =>	['lyrics-songs','http://letras.terra.com.br/winamp.php?musica=%t&artista=%a',undef,
+	lyricssongs =>	['lyrics-songs',sub {  ::ReplaceFields($_[0], "http://letras.terra.com.br/winamp.php?musica=%t&artista=%a", sub {::url_escapeall(::superlc($_[0]));})  },undef,
 			sub {	my $l=html_extract($_[0],div=>'letra');
 				$l=~s#<div id="cabecalho">.*?</div>##s if $l; #remove header with title and artist links
 				my $ref=\$_[0];
@@ -70,8 +70,8 @@ my %Sites=	# id => [name,url,?post?,function]	if the function return 1 => lyrics
 			}],
 	lyricwiki =>	[lyricwiki => 'http://lyrics.wikia.com/%a:%t',undef,
 			 sub {	return 0,'http://lyrics.wikia.com/'.$1 if $_[0]=~m#<span class="redirectText"><a href="/([^"]+)"#;
-				$_[0]=~s!.*<div class='lyricbox'>.*?((?:&\#\d+;|<br ?/>){5,}).*!$1!s; #keep only the "lyric box"
-				return 0 if $_[0]=~m/&#91;&#46;&#46;&#46;&#93;<br/; # truncated lyrics : "[...]" => not auto-saved
+				$_[0]=~s!.*<div class='lyricbox'>.*?((?:&\#\d+;|<br ?/>|</?[bi]>){5,}).*!$1!s; #keep only the "lyric box"
+				return 0 if $_[0]=~m!&#91;&#46;&#46;&#46;&#93;(?:<br ?/>)*<i>!; # truncated lyrics : "[...]" followed by italic explanation => not auto-saved
 				return !!$1;
 			}],
 	#lyricwikiapi => [lyricwiki => 'http://lyricwiki.org/api.php?artist=%a&song=%t&fmt=html',undef,
@@ -189,8 +189,7 @@ sub cancel
 
 sub prefbox
 {	my $vbox=Gtk2::VBox->new(::FALSE, 2);
-	my $entry=::NewPrefEntry(OPT.'PathFile' => _"Lyrics file :", width=>30);
-_"Lyrics file name format",
+	my $entry=::NewPrefEntry(OPT.'PathFile' => _"Lyrics file :", width=>30, tip=> _"Lyrics file name format" );
 	my $preview= Label::Preview->new(preview => \&filename_preview, event => 'CurSong Option', noescape=>1,wrap=>1);
 	my $autosave=::NewPrefCheckButton(OPT.'AutoSave' => _"Auto-save positive finds", tip=>_"only works with some lyrics source and when the lyrics tab is active");
 	my $embed=::NewPrefCombo(OPT.'PreferEmbeddedLyrics', { 0=> _"lyrics file", 1=> _"file tag"},
@@ -258,6 +257,16 @@ sub ChooseFont
 	$dialog->destroy;
 }
 
+sub Set_message
+{	my ($self,$text) = @_;
+	$self->{buffer}->set_text("");
+	my $iter=$self->{buffer}->get_start_iter;
+	my $fontsize=$self->style->font_desc;
+	my $tag_noresults=$self->{buffer}->create_tag(undef,justification=>'center',font=>$fontsize*2,foreground_gdk=>$self->style->text_aa("normal"));
+	$self->{buffer}->insert_with_tags($iter,"\n$text",$tag_noresults);
+	$self->{buffer}->set_modified(0);
+}
+
 sub Back_cb
 {	my $self=::find_ancestor($_[0],__PACKAGE__);
 	my $url=pop @{$self->{history}};
@@ -291,8 +300,7 @@ sub load_from_web
 	if ($next)
 	{	$site = shift @{$self->{trynext}};
 		if (!$site)
-		{	$self->{buffer}->set_text(_"Not found.");
-			$self->{buffer}->set_modified(0);
+		{	$self->Set_message(_"No lyrics found");
 			return;
 		}
 	}
@@ -377,8 +385,7 @@ sub html_extract
 
 sub load_url
 {	my ($self,$url,$post,$check)=@_;
-	$self->{buffer}->set_text(_"Loading...");
-	$self->{buffer}->set_modified(0);
+	$self->Set_message(_"Loading...");
 	$self->cancel;
 	warn "lyrics : loading $url\n";# if $::debug;
 	$self->{url}=$url;
