@@ -5,7 +5,7 @@
 # it under the terms of the GNU General Public License version 3, as
 # published by the Free Software Foundation
 
-=gmbplugin MPRIS2
+=for gmbplugin MPRIS2
 name	MPRIS v2
 title	MPRIS v2 support
 desc	Allows controlling gmusicbrowser via DBus using the MPRIS v2.0 standard
@@ -141,11 +141,11 @@ sub Quit
 }
 
 dbus_property('CanQuit', 'bool', 'read');
-sub CanQuit {1}
+sub CanQuit {dbus_boolean(1)}
 dbus_property('CanRaise', 'bool', 'read');
-sub CanRaise {1}
+sub CanRaise {dbus_boolean(1)}
 dbus_property('HasTrackList', 'bool', 'read');
-sub HasTrackList {0}
+sub HasTrackList {dbus_boolean(0)}
 dbus_property('Identity', 'string', 'read');
 sub Identity { 'gmusicbrowser' }
 dbus_property('DesktopEntry', 'string', 'read');
@@ -153,7 +153,7 @@ sub DesktopEntry { 'gmusicbrowser' }
 dbus_property('SupportedUriSchemes', ['array','string'], 'read');
 sub SupportedUriSchemes { return ['file']; }
 dbus_property('SupportedMimeTypes', ['array','string'], 'read');
-sub SupportedMimeTypes { return [qw(audio/mpeg application/ogg audio/x-flac audio/x-musepack audio/x-m4a)]; } #FIXME
+sub SupportedMimeTypes { return [qw(application/ogg audio/flac audio/mpeg audio/ogg audio/x-flac audio/x-m4a audio/x-musepack)]; } #FIXME
 
 dbus_method('Next',	[], [], 'org.mpris.MediaPlayer2.Player', {no_return=>1});
 sub Next	{ ::NextSong(); }
@@ -191,9 +191,11 @@ sub Seek
 	}
 }
 
-dbus_method('SetPosition', [['struct','objectpath','int64']], [], 'org.mpris.MediaPlayer2.Player', {no_return=>1});
+dbus_method('SetPosition', ['objectpath','int64'], [], 'org.mpris.MediaPlayer2.Player', {no_return=>1});
 sub SetPosition
-{	my ($ID,$position)= @{ $_[1] };
+{	my (undef,$ID,$position)= (@_);
+	return unless $ID=~m#^/Song/(\d+)$#;
+	$ID=$1;
 	return unless defined $::SongID && $ID==$::SongID;
 	$position/=1_000_000;
 	my $length= Songs::Get($::SongID,'length');
@@ -237,11 +239,11 @@ sub LoopStatus
 }
 
 dbus_property('Rate', 'double', 'readwrite', 'org.mpris.MediaPlayer2.Player');
-sub Rate {1}
+sub Rate {dbus_double(1)}
 dbus_property('MinimumRate', 'double', 'read', 'org.mpris.MediaPlayer2.Player');
-sub MinimumRate {1}
+sub MinimumRate {dbus_double(1)}
 dbus_property('MaximumRate', 'double', 'read', 'org.mpris.MediaPlayer2.Player');
-sub MaximumRate {1}
+sub MaximumRate {dbus_double(1)}
 
 dbus_property('Shuffle', 'bool', 'readwrite', 'org.mpris.MediaPlayer2.Player');
 sub Shuffle
@@ -257,13 +259,13 @@ sub Metadata
 
 dbus_property('Volume', 'double', 'readwrite', 'org.mpris.MediaPlayer2.Player');
 sub Volume
-{	if (defined $_[1]) { my $v=$_[1]; $v=0 if $v<0; ::ChangeVol($v); }
+{	if (defined $_[1]) { my $v=$_[1]; $v=0 if $v<0; ::ChangeVol(100*$v); }
 	else { return dbus_double($::Volume/100); }
 }
 
 dbus_property('Position', 'int64', 'read', 'org.mpris.MediaPlayer2.Player');
 sub Position
-{	return ($::PlayTime||0) *1_000_000;
+{	return dbus_int64( ($::PlayTime||0) *1_000_000 );
 }
 
 dbus_property('CanGoNext', 'bool', 'read', 'org.mpris.MediaPlayer2.Player');
@@ -282,22 +284,37 @@ dbus_property('CanPlay', 'bool', 'read', 'org.mpris.MediaPlayer2.Player');
 sub CanPlay
 {	return dbus_boolean( defined $::SongID );
 }
+dbus_property('CanPause', 'bool', 'read', 'org.mpris.MediaPlayer2.Player');
+sub CanPause
+{	return dbus_boolean( defined $::SongID );
+}
 dbus_property('CanSeek', 'bool', 'read', 'org.mpris.MediaPlayer2.Player');
 sub CanSeek
 {	return dbus_boolean( defined $::SongID ); #will need to check if stream when supported
 }
 dbus_property('CanControl', 'bool', 'read', 'org.mpris.MediaPlayer2.Player');
-sub CanControl {1}
+sub CanControl {dbus_boolean(1)}
 
 # 'org.mpris.MediaPlayer2.Player','Metadata'
 sub GetMetadata_from
 {	my $ID=shift;
-	return {} unless defined $ID;
+
+	# Net::DBus support for properties is incomplete, the following use undocumented functions to force it to use the correct data types for the returned values
+	my $type=
+	 [ &Net::DBus::Binding::Message::TYPE_DICT_ENTRY,
+		[ &Net::DBus::Binding::Message::TYPE_STRING,
+			[ &Net::DBus::Binding::Message::TYPE_VARIANT,
+				[],
+	 ]]];
+	#my ($type)= Net::DBus::Binding::Introspector->_convert(['dict','string',['variant']]); #works too, not sure which one is best
+
+	return Net::DBus::Binding::Value->new($type,{}) unless defined $ID;
+
 	my %h;
-	$h{$_}=Songs::Get($ID,$_) for qw/title album artist comment length track disc year album_artist uri album_picture rating bitrate samprate genre playcount/;
+	$h{$_}=Songs::Get($ID,$_) for qw/title album artist comment length track disc year album_artist uri album_picture rating bitrate samprate genre playcount/, grep Songs::FieldEnabled($_), qw/composer lyricist bpm/;
 	my %r= #return values
 	(	'mpris:length'		=> dbus_int64($h{'length'}*1_000_000),
-		'mpris:trackid'		=> dbus_string($ID), #FIXME should contain a string that uniquely identifies the track within the scope of the playlist
+		'mpris:trackid'		=> dbus_object_path("/Song/$ID"), #FIXME should contain a string that uniquely identifies the track within the scope of the playlist
 		'xesam:album'		=> dbus_string($h{album}),
 		'xesam:albumArtist'	=> dbus_array([ $h{album_artist} ]),
 		'xesam:artist'		=> dbus_array([ $h{artist} ]),
@@ -310,10 +327,9 @@ sub GetMetadata_from
 		'xesam:trackNumber'	=> ( $h{track} ? dbus_int32($h{track}) : undef),
 		'xesam:url'		=> dbus_string( $h{uri} ),
 		'xesam:useCount'	=> dbus_int32($h{playcount}),
-		# FIXME check if field exists
-		#'xesam:audioBPM'	=>
-		#'xesam:composer'	=> dbus_array([ $h{composer} ]),
-		#'xesam:lyricist',	=> dbus_array([ $h{lyricist} ]),
+		'xesam:audioBPM'	=> ($h{bpm} ? dbus_int32($h{bpm}) : undef),
+		'xesam:composer'	=> ($h{composer}||'' ne '' ? dbus_array([ $h{composer} ]) : undef),
+		'xesam:lyricist',	=> ($h{lyricist}||'' ne '' ? dbus_array([ $h{lyricist} ]) : undef),
 	);
 	my $rating=$h{rating};
 	if (defined $rating && length $rating) { $r{'xesam:userRating'}=dbus_double($rating/100); }
@@ -323,16 +339,57 @@ sub GetMetadata_from
 
 	delete $r{$_} for grep !defined $r{$_}, keys %r;
 
-	# Net::DBus support for properties is incomplete, the following use undocumented functions to force it to use the correct data types for the returned values
-	my $type=
-	 [ &Net::DBus::Binding::Message::TYPE_DICT_ENTRY,
-		[ &Net::DBus::Binding::Message::TYPE_STRING,
-			[ &Net::DBus::Binding::Message::TYPE_VARIANT,
-				[],
-	 ]]];
-	#my ($type)= Net::DBus::Binding::Introspector->_convert(['dict','string',['variant']]); #works too, not sure which one is best
 	return Net::DBus::Binding::Value->new($type,\%r);
 }
 
+
+
+
+
+### patched version of Net::DBus::Object::_dispatch_all_prop_read v1.0.0 to support properties of different types
+### Net::DBus::Object::_dispatch_all_prop_read was added in Net::DBus v1.0.0 to support the org.freedesktop.DBus.Properties.GetAll method
+
+no warnings 'redefine';
+
+sub Net::DBus::Object::_dispatch_all_prop_read {
+    my $self = shift;
+    my $connection = shift;
+    my $message = shift;
+
+    my $ins = $self->_introspector;
+
+    if (!$ins) {
+	return $connection->make_error_message($message,
+					       "org.freedesktop.DBus.Error.Failed",
+					       "no introspection data exported for properties");
+    }
+
+    my ($pinterface) = $ins->decode($message, "methods", "Get", "params");
+
+    my %values = ();
+    foreach my $pname ($ins->list_properties($pinterface)) {
+	unless ($ins->is_property_readable($pinterface, $pname)) {
+		next; # skip write-only properties
+	}
+	$values{$pname} = eval {
+	    $self->$pname;
+	};
+	if ($@) {
+	    return $connection->make_error_message($message,
+						   "org.freedesktop.DBus.Error.Failed",
+						   "error reading '$pname' in interface '$pinterface': $@");
+	}
+    }
+
+    my $reply = $connection->make_method_return_message($message);
+
+### patch : fix method name, which fix return type
+     $self->_introspector->encode($reply, "methods", "GetAll", "returns", \%values);
+###  $self->_introspector->encode($reply, "methods", "Get", "returns", \%values);
+### end of patch
+    return $reply;
+}
+
+
 1;
 
